var encoder_8h =
[
    [ "ResizeCfg", "structResizeCfg.html", "structResizeCfg" ],
    [ "PartitionCfg", "structPartitionCfg.html", "structPartitionCfg" ],
    [ "IntraModeCfg", "structIntraModeCfg.html", "structIntraModeCfg" ],
    [ "TxfmSizeTypeCfg", "structTxfmSizeTypeCfg.html", "structTxfmSizeTypeCfg" ],
    [ "CompoundTypeCfg", "structCompoundTypeCfg.html", "structCompoundTypeCfg" ],
    [ "SuperResCfg", "structSuperResCfg.html", "structSuperResCfg" ],
    [ "KeyFrameCfg", "structKeyFrameCfg.html", "structKeyFrameCfg" ],
    [ "RateControlCfg", "structRateControlCfg.html", "structRateControlCfg" ],
    [ "AlgoCfg", "structAlgoCfg.html", "structAlgoCfg" ],
    [ "AV1EncoderConfig", "structAV1EncoderConfig.html", "structAV1EncoderConfig" ],
    [ "FrameProbInfo", "structFrameProbInfo.html", "structFrameProbInfo" ],
    [ "inter_modes_info", "structinter__modes__info.html", "structinter__modes__info" ],
    [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
    [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
    [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
    [ "AV1EncAllIntraMultiThreadInfo", "structAV1EncAllIntraMultiThreadInfo.html", "structAV1EncAllIntraMultiThreadInfo" ],
    [ "RestoreStateBuffers", "structRestoreStateBuffers.html", "structRestoreStateBuffers" ],
    [ "RestUnitSearchInfo", "structRestUnitSearchInfo.html", "structRestUnitSearchInfo" ],
    [ "AV1LrPickStruct", "structAV1LrPickStruct.html", "structAV1LrPickStruct" ],
    [ "PrimaryMultiThreadInfo", "structPrimaryMultiThreadInfo.html", "structPrimaryMultiThreadInfo" ],
    [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
    [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
    [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
    [ "GlobalMotionInfo", "structGlobalMotionInfo.html", "structGlobalMotionInfo" ],
    [ "InitialDimensions", "structInitialDimensions.html", "structInitialDimensions" ],
    [ "InterpSearchFlags", "structInterpSearchFlags.html", "structInterpSearchFlags" ],
    [ "MotionVectorSearchParams", "structMotionVectorSearchParams.html", "structMotionVectorSearchParams" ],
    [ "RefreshFrameInfo", "structRefreshFrameInfo.html", "structRefreshFrameInfo" ],
    [ "ResizePendingParams", "structResizePendingParams.html", "structResizePendingParams" ],
    [ "RefFrameDistanceInfo", "structRefFrameDistanceInfo.html", "structRefFrameDistanceInfo" ],
    [ "WinnerModeParams", "structWinnerModeParams.html", "structWinnerModeParams" ],
    [ "ExtRefreshFrameFlagsInfo", "structExtRefreshFrameFlagsInfo.html", "structExtRefreshFrameFlagsInfo" ],
    [ "ExternalFlags", "structExternalFlags.html", "structExternalFlags" ],
    [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
    [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
    [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
    [ "AV1_COMP_DATA", "structAV1__COMP__DATA.html", "structAV1__COMP__DATA" ],
    [ "AV1_PRIMARY", "structAV1__PRIMARY.html", "structAV1__PRIMARY" ],
    [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
    [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
    [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
    [ "NUM_RECODES_PER_FRAME", "encoder_8h.html#a7c7530c349e3a9478e879f6d16884282", null ],
    [ "MAX_PARALLEL_FRAMES", "encoder_8h.html#af2bb9f0bb51c031007f05054a3bf6b07", null ],
    [ "AV1EncoderConfig", "encoder_8h.html#ae37f210917b9733abc7ca81445427d71", null ],
    [ "InterModesInfo", "encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718", null ],
    [ "RestoreStateBuffers", "encoder_8h.html#add3c378ea62064e99094302a4af0fe64", null ],
    [ "PrimaryMultiThreadInfo", "encoder_8h.html#a1e0a95f3ba85551b4280ef86a45235bb", null ],
    [ "MultiThreadInfo", "encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f", null ],
    [ "AV1_COMP_DATA", "encoder_8h.html#a4a823cfecd8aa8c27bd6670df6ad9713", null ],
    [ "AV1_PRIMARY", "encoder_8h.html#a9af93120431b9d96ca04670151ea562c", null ],
    [ "AV1_COMP", "encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f", null ],
    [ "EncodeFrameInput", "encoder_8h.html#a246db68993252fe81c1e5a911575efb4", null ],
    [ "EncodeFrameParams", "encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda", null ],
    [ "COST_UPDATE_TYPE", "encoder_8h.html#a03bce75164cb579c775759205ed26055", [
      [ "COST_UPD_SB", "encoder_8h.html#a03bce75164cb579c775759205ed26055a7ab17ad52ce554037df368d89cef2c02", null ],
      [ "COST_UPD_SBROW", "encoder_8h.html#a03bce75164cb579c775759205ed26055a0387b2a2bbc01b142f3716c18a97fe9d", null ],
      [ "COST_UPD_TILE", "encoder_8h.html#a03bce75164cb579c775759205ed26055a6e437058362eef3c17fc5c856202dee3", null ],
      [ "COST_UPD_OFF", "encoder_8h.html#a03bce75164cb579c775759205ed26055a6f0f4239b7fc9f98980631093f885cc0", null ],
      [ "NUM_COST_UPDATE_TYPES", "encoder_8h.html#a03bce75164cb579c775759205ed26055a7155daf31c8b01be1e8093e8e36ce6fb", null ]
    ] ],
    [ "LOOPFILTER_CONTROL", "encoder_8h.html#a763875a39b7bd1931c473816cce5b526", [
      [ "LOOPFILTER_NONE", "encoder_8h.html#a763875a39b7bd1931c473816cce5b526abcdd38fc3c9d28ee7bc6f239d6398c80", null ],
      [ "LOOPFILTER_ALL", "encoder_8h.html#a763875a39b7bd1931c473816cce5b526a0ef541f183d3eca96af1646512a5b8a2", null ],
      [ "LOOPFILTER_REFERENCE", "encoder_8h.html#a763875a39b7bd1931c473816cce5b526ab09c9bc921ce3db1d2de31f412320b2e", null ],
      [ "LOOPFILTER_SELECTIVELY", "encoder_8h.html#a763875a39b7bd1931c473816cce5b526a2e00e0285db43d464e21e0669918cdc3", null ]
    ] ],
    [ "SKIP_APPLY_POSTPROC_FILTER", "encoder_8h.html#abcba64e654f5bcb3ba1449668c424906", [
      [ "SKIP_APPLY_RESTORATION", "encoder_8h.html#abcba64e654f5bcb3ba1449668c424906a41aadbdfa9e5c7d0b653e2f26753ed06", null ],
      [ "SKIP_APPLY_SUPERRES", "encoder_8h.html#abcba64e654f5bcb3ba1449668c424906aae78505d57c712c615f99f18f7fefad0", null ],
      [ "SKIP_APPLY_CDEF", "encoder_8h.html#abcba64e654f5bcb3ba1449668c424906a25996ba4d7d8bc9836af3a40689741f3", null ],
      [ "SKIP_APPLY_LOOPFILTER", "encoder_8h.html#abcba64e654f5bcb3ba1449668c424906af1fefe2fd9bbb67acadecac23e931f61", null ]
    ] ],
    [ "av1_receive_raw_frame", "group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37", null ],
    [ "av1_get_compressed_data", "group__high__level__algo.html#ga4017ec9e9cfd7bd461775266c80ff46d", null ],
    [ "av1_encode", "group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7", null ],
    [ "has_no_stats_stage", "group__two__pass__algo.html#ga737bbff8d05e931b73b4321a0fa35d0e", null ]
];